@@ -73,10 +73,11 @@ mnl_fd2_ova <- function(model,
   # Names of variables in model (without the "list" character in the vector)
   variables <- as.character(attr(model$terms, "variables"))[-1]
 
-  if(!(xvari %in% variables) == TRUE){
+  if (!(xvari %in% variables) == TRUE){
     stop("x-variable is not an independent variable in the model. There might be a typo.")
   }
 
+
   # Create list that is returned in the end.
   output <- list()
 
@@ -112,6 +113,11 @@ mnl_fd2_ova <- function(model,
   iv <- variables[2:length(variables)]
   output[["IV"]] <- iv
 
+  # Variables have to be numeric
+  if (sum(apply(data[, iv], 2, class) %in% c("numeric", "integer")) < ncol(data[, iv])) {
+    stop("Please supply data that consists of numeric values. The package can not handle factor or character variables, yet. For workarounds, please take a look at the github issues (https://github.com/ManuelNeumann/MNLpred/issues/1). The problem will be fixed with the 0.1.0 release.")
+  }
+
   # Name of dependent variable
   dv <- variables[1]
   output[["DV"]] <- dv
